@@ -78,11 +78,13 @@ invisible(hurricanes)
 #' @name plot_hurricanes
 #' @param dataset Name of the tibble generated by `get_hurricanes`
 #' @param print (boolean) Display hurricane ggplot2 chart, defaults to TRUE. Use FALSE to not display chart.
+#' @param cat (string) Select which category of hurricane to plot. May be "major", "hurricane", or "storm". Defaults to "major".
 #'
 #' @return Invisibly returns a ggplot2 object with hurricanes chart
 #'
 #' @details `plot_hurricanes` invisibly returns a ggplot2 object with a pre-defined hurricane data chart using data from `get_hurricanes`.
 #' By default the chart is also displayed. Smooths using ggplot2's built-in loess smoother. Users may further modify the output ggplot2 chart.
+#' Categories may be "major" (category 3-5), "hurricane" (category 1-5), or "storm" (named storm).
 #'
 #' @import ggplot2
 #'
@@ -103,15 +105,25 @@ invisible(hurricanes)
 #' @author Hernando Cortina, \email{hch@@alum.mit.edu}
 #'
 #' @export
-plot_hurricanes <- function(dataset = get_hurricanes(), print=TRUE) {
+plot_hurricanes <- function(dataset = get_hurricanes(), cat='major', print=TRUE) {
 
-  if (is.null(dataset)) return(invisible(NULL))
+  if(cat=='major') {dataset <- dataset[,c('Year', 'RevisedMajorHurricanes')]
+                    sub_label <- 'Major Hurricanes (category 3-5)' }
 
-    plot <- ggplot(dataset, aes(x=Year, y=RevisedMajorHurricanes)) +geom_line(alpha=0.75, aes(color='Hurricanes')) + theme_bw(base_size=12) +
+  if(cat=='hurricane') {dataset <- dataset[,c('Year', 'RevisedHurricanes')]
+                        sub_label <- 'Hurricanes (category 1-5)' }
+
+  if(cat=='storm') {dataset <- dataset[,c('Year', 'RevisedNamedStorms')]
+                    sub_label <- 'Named Storms' }
+
+  colnames(dataset)[2] <- 'hurr_type'
+  if (is.null(dataset) | ncol(dataset)!=2) return(invisible(NULL))
+
+    plot <- ggplot(dataset, aes(x=Year, y=hurr_type)) +geom_line(alpha=0.75, aes(color='Hurricanes')) + theme_bw(base_size=12) +
     scale_x_continuous(name=NULL, breaks=seq(1850, 2025,25)) +
     scale_y_continuous(n.breaks = 8) +geom_smooth(size=1.1, se=F, aes(color='Loess smooth')) +
     scale_color_manual(name=NULL, values=c('dodgerblue2','firebrick1')) +theme(legend.position = c(0.15, 0.825),legend.background=element_blank()) +
-    labs(title='North Atlantic Hurricane Basin', subtitle='Major Hurricanes (category 3-5)',
+    labs(title='North Atlantic Hurricane Basin', subtitle = sub_label,
         y='Number per season', caption='Source: NOAA Hurricane Research Division, HURDAT2 re-analysis\nhttps://www.aoml.noaa.gov/hrd/hurdat/Data_Storm.html')
 
   if (print) suppressMessages( print(plot) )
