@@ -112,7 +112,7 @@ if (is.null(dataset)) return(invisible(NULL))
 
 plot <- ggplot(dataset, aes(x=Year, y=`J-D`)) +geom_line(alpha=0.75, aes(color='Annual mean')) + theme_bw(base_size=12) +
   scale_x_date(name=NULL, limits=c(as.Date('1878-01-01'), ymd(max(dataset$Year))), date_breaks='15 years', date_labels='%Y') +
-  scale_y_continuous(n.breaks = 8) +geom_smooth(size=1.1, se=F, span=0.3, aes(color='Loess smoothing')) +
+  scale_y_continuous(n.breaks = 9) +geom_smooth(size=1.1, se=F, span=0.3, aes(color='Loess smoothing')) +
   labs(title='Global Land-Ocean Temperature Index (LOTI)', subtitle='Global surface temperature relative to 1951-1980 mean',
        y='Temperature Anomaly (C\U00B0)', caption='Source: NASA Goddard Institute for Space Studies\nhttps://data.giss.nasa.gov/gistemp/') +
   scale_color_manual(name=NULL, values=c('dodgerblue2','firebrick1')) +theme(legend.position = c(0.175, 0.825),legend.background=element_blank())
@@ -170,7 +170,7 @@ plot_temp_monthly <- function(dataset = get_temp(), print=TRUE) {
 
   plot <- ggplot(dataset, aes(x=Date, y=Anomaly)) +geom_line(alpha=0.75, aes(color='Monthly mean')) + theme_bw(base_size=12) +
     scale_x_date(name=NULL, limits=c(as.Date('1878-01-01'), ymd(max(dataset$Year))), date_breaks='15 years', date_labels='%Y') +
-    scale_y_continuous(n.breaks = 8) +geom_smooth(size=1.1, se=F, span=0.3, aes(color='Loess smoothing')) +
+    scale_y_continuous(n.breaks = 10) +geom_smooth(size=1.1, se=F, span=0.3, aes(color='Loess smoothing')) +
     labs(title='Global Land-Ocean Temperature Index (LOTI)', subtitle='Global surface temperature relative to 1951-1980 mean',
          y='Temperature Anomaly (C\U00B0)', caption='Source: NASA Goddard Institute for Space Studies\nhttps://data.giss.nasa.gov/gistemp/') +
     scale_color_manual(name=NULL, values=c('firebrick1','dodgerblue2')) +
@@ -190,6 +190,8 @@ plot_temp_monthly <- function(dataset = get_temp(), print=TRUE) {
 #' @name plot_temp_scatter
 #' @param dataset Name of the tibble generated by `get_temp`
 #' @param print (boolean) Display temperature anomaly ggplot2 chart, defaults to TRUE. Use FALSE to not display chart.
+#' @param labellatest (boolean) Display date of latest value, default = TRUE
+#' @param labelmax (boolean) Display date of max value, default = FALSE
 #'
 #' @return Invisibly returns a ggplot2 object with temperature anomaly chart
 #'
@@ -218,7 +220,7 @@ plot_temp_monthly <- function(dataset = get_temp(), print=TRUE) {
 #'
 #' @export
 
-plot_temp_scatter <- function(dataset = get_temp(), print=TRUE) {
+plot_temp_scatter <- function(dataset = get_temp(), print=TRUE, labelmax=FALSE, labellatest=TRUE) {
 
   if (is.null(dataset)) return(invisible(NULL))
 
@@ -227,9 +229,6 @@ plot_temp_scatter <- function(dataset = get_temp(), print=TRUE) {
 
   dataset <- dataset |> mutate(Date = ceiling_date(ym(paste(year(Year), Month)), 'month') - days(1))
 
-  dataset <- dataset |> mutate(max = ifelse(Anomaly == max(dataset$Anomaly), T, F))
-  dataset <- dataset |> mutate(name = ifelse(max == T, substr(as.character(Date),1,7), ''))
-
   col_strip <- RColorBrewer::brewer.pal(11, "RdBu")[-(5:7)]
 
   plot <- ggplot(dataset, aes(x=Year, y=Anomaly, color=Anomaly)) + geom_point(size=1) + theme_bw(base_size=12) +
@@ -237,8 +236,19 @@ plot_temp_scatter <- function(dataset = get_temp(), print=TRUE) {
     scale_y_continuous(n.breaks = 8)  +
     labs(title='Global Land-Ocean Temperature Index (LOTI)', subtitle='Global surface temperature relative to 1951-1980 mean', color='',
          y='Monthly Temperature Anomaly (C\U00B0)', caption='Source: NASA Goddard Institute for Space Studies\nhttps://data.giss.nasa.gov/gistemp/') +
-    theme(legend.position = c(0.09, 0.85),legend.background=element_blank() ) +
-    scale_color_gradientn(colors = rev(col_strip)) + geom_text(aes(y = Anomaly+0.1, label=name), size=3)
+    theme(legend.position='inside', legend.position.inside = c(0.09, 0.85),legend.background=element_blank() ) +
+    scale_color_gradientn(colors = rev(col_strip))
+
+  if (labelmax) {
+    dataset <- dataset |> mutate(max = ifelse(Anomaly == max(dataset$Anomaly), T, F))
+    dataset <- dataset |> mutate(name = ifelse(max == T, substr(as.character(Date),1,7), ''))
+    plot <- plot + geom_text(aes(y = Anomaly+0.1, label=dataset$name), size=3) }
+
+
+  if (labellatest) {
+    if ( !exists("name", dataset) ) dataset$name <- ''
+    dataset[nrow(dataset),'name'] <- substr(as.character(pull(dataset[nrow(dataset),'Date'])), 1, 7)
+    plot <- plot + geom_text(aes(y = Anomaly+0.2, label=dataset$name), size=3) }
 
   if (print) suppressMessages( print(plot) )
   invisible(plot)
